@@ -21,7 +21,7 @@ def get_target_color(img):
         return [0] * len(img.load()[0,0])
 
 class ImageLayer:
-    def __init__(self, image, pixelcoords=[], color=(0,0,0,255)):
+    def __init__(self, image, pixelcoords, color):
         self.pxcs = set(pixelcoords)
         self.color = tuple(color)
         self.image = image
@@ -68,7 +68,7 @@ class ImageLayer:
         return self.toimage().save(*args, **kwargs)
     
     def toimage(self):
-        img = Image.new(self.image.mode, self.image.size, color=(0,0,0,255))
+        img = Image.new(self.image.mode, self.image.size, self.color)
         px = img.load()
         for x, y in self.pxcs:
             px[x,y] = self.color
@@ -187,7 +187,7 @@ class LayeredImage:
                     continue
                 ImageDraw.floodfill(orig, xy=(x,y), value=target_color)
                 group = filter(lambda x: px[x] == target_color, coordgen(*orig.size))
-                layer = ImageLayer(self.image, group, color=(255,255,255,255))
+                layer = ImageLayer(self.image, group, color=target_color)
                 del group
                 for pixel in layer.pxcs:
                     if pixel not in pixels:
